aboutsummaryrefslogtreecommitdiffstats
path: root/ttcn3-tcpdump-start.sh
diff options
context:
space:
mode:
Diffstat (limited to 'ttcn3-tcpdump-start.sh')
-rwxr-xr-xttcn3-tcpdump-start.sh18
1 files changed, 9 insertions, 9 deletions
diff --git a/ttcn3-tcpdump-start.sh b/ttcn3-tcpdump-start.sh
index 747002be..b8ad01ac 100755
--- a/ttcn3-tcpdump-start.sh
+++ b/ttcn3-tcpdump-start.sh
@@ -1,6 +1,6 @@
#!/bin/sh
-PIDFILE=/tmp/tcpdump.pid
+PIDFILE=/tmp/dumper.pid
TCPDUMP=/usr/sbin/tcpdump
TESTCASE=$1
@@ -16,19 +16,19 @@ if [ -e $PIDFILE ]; then
rm $PIDFILE
fi
-# NOTE: This requires you to be root or something like
-# "laforge ALL=NOPASSWD: /usr/sbin/tcpdump, /bin/kill" in your sudoers file
if [ "$(id -u)" = "0" ]; then
- CMD=$TCPDUMP
+ CMD="$TCPDUMP -U"
else
- CMD="sudo $TCPDUMP"
+# NOTE: This requires you to be root or something like
+# "laforge ALL=NOPASSWD: /usr/sbin/tcpdump, /bin/kill" in your sudoers file
+ CMD="sudo $TCPDUMP -U"
fi
-$CMD -U -s 1500 -n -i any -w "$TTCN3_PCAP_PATH/$TESTCASE.pcap" >$TTCN3_PCAP_PATH/$TESTCASE.pcap.stdout 2>&1 &
+$CMD -s 1500 -n -i any -w "$TTCN3_PCAP_PATH/$TESTCASE.pcap" >$TTCN3_PCAP_PATH/$TESTCASE.pcap.stdout 2>&1 &
PID=$!
echo $PID > $PIDFILE
# Wait until tcpdump creates the pcap file and starts recording.
# We generate some traffic until we see tcpdump catches it.
# Timeout is 10 seconds.
ping 127.0.0.1 >/dev/null 2>&1 &
PID=$!
@@ -36,7 +36,7 @@ i=0
while [ ! -f "$TTCN3_PCAP_PATH/$TESTCASE.pcap" ] ||
[ "$(stat -c '%s' "$TTCN3_PCAP_PATH/$TESTCASE.pcap")" -eq 32 ]
do
- echo "Waiting for tcpdump to start... $i"
+ echo "Waiting for packet dumper to start... $i"
sleep 1
i=$((i+1))
if [ $i -eq 10 ]; then
@@ -16,19 +16,19 @@ if [ -e $PIDFILE ]; then
PID=$!
echo $PID > $PIDFILE
-# Wait until tcpdump creates the pcap file and starts recording.
-# We generate some traffic until we see tcpdump catches it.
+# Wait until packet dumper creates the pcap file and starts recording.
+# We generate some traffic until we see packet dumper catches it.
# Timeout is 10 seconds.
ping 127.0.0.1 >/dev/null 2>&1 &